/*  
 *  xconvers - GTK+ client for amateur radio convers
 *  Copyright (C) 2000-2001 Joop Stakenborg <pa4tu@amsat.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/*
 *  color.h
 */

#include <gtk/gtk.h>

#define STATUS_MESSAGE  1
#define USER_MESSAGE    2
#define PRIVATE_MESSAGE 3
#define DEFAULT_MESSAGE 4
#define UNKNOWN_MESSAGE 5

void maintext_add(gchar *msg, gint messagetype);
gint getcolor(gchar *call);
gchar *color_parse(gchar value[100]);
void setbuttoncolor(gchar *buttonname, GdkColor buttoncolor);
void updatepreview(GdkColor selectedcolor);
